<?php
/*
Plugin Name: WebToNative Offer Card
Description: Embed an offer card on any page with customizable settings.
Version: 1.0
Author: webtonative
*/

if (!defined('ABSPATH')) {
    exit;
}

// Enqueue the necessary scripts
function wtn_offercard_enqueue_scripts()
{
    wp_enqueue_script('wtn-offercard-script', plugin_dir_url(__FILE__) . 'js/wtn-offercard.js', array(), '1.0', true);
}
add_action('wp_enqueue_scripts', 'wtn_offercard_enqueue_scripts');

// Create the shortcode
function wtn_offercard_shortcode($atts)
{
    $defaults = array(
        'action_url' => 'https://www.webtonative.com',
        'button_text_color' => '#FFFFFF',
        'button_bg_color' => '#111111',
        'button_text' => 'WebToNative',
        'card_size' => 'SMALL', // SMALL | FULL_SCREEN | FULL_WIDTH   (required)
        'card_position' => 'RIGHT', // LEFT | RIGHT (SMALL size card position default position right) (Has no impact in case of FULL_SCREEN | FULL_WIDTH )
        'card_bg_color' => '#000000',
        'content_type' => 'IMAGE', // IMAGE | VIDEO
        'content_url' => 'https://wallpaperaccess.com/full/2083830.jpg',
        'id' => '1',
        'schedule_duration' => 9,
        'schedule_unit' => 'minutes' // minutes | hours | days
    );

    // Merge global settings with shortcode attributes
    $options = shortcode_atts($defaults, $atts);

    $output = '<div id="wtn-offercard"></div>';
    $output .= '
    <script src="https://unpkg.com/webtonative@1.0.59/webtonative.min.js"></script>
    <script>
        window.WTN.loadOfferCard({
            action: "showOfferCard",
            data: {
                action: {
                    url: "' . esc_url($options['action_url']) . '",
                    button: {
                        textColor: "' . esc_attr($options['button_text_color']) . '",
                        bgColor: "' . esc_attr($options['button_bg_color']) . '",
                        text: "' . esc_attr($options['button_text']) . '"
                    }
                },
                id: "' . esc_attr($options['id']) . '",
                card: {
                    size: "' . esc_attr($options['card_size']) . '",
                    position: "' . esc_attr($options['card_position']) . '",
                    bgColor: "' . esc_attr($options['card_bg_color']) . '",
                    content: {
                        type: "' . esc_attr($options['content_type']) . '",
                        url: "' . esc_url($options['content_url']) . '"
                    }
                },
                schedule: {
                    duration: ' . intval($options['schedule_duration']) . ',
                    unit: "' . esc_attr($options['schedule_unit']) . '"
                }
            }
        });
    </script>';
    return $output;
}

add_shortcode('wtn_offercard', 'wtn_offercard_shortcode');
