<?php
/*
Plugin Name: Webtonative MediaPlayer Native Control
Description: Integrates Webtonative MediaPlayer with native device media controls and provides admin options to enable or disable audio and video monitoring.
Version: 1.2
Author: webtonative
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Enqueue JavaScript file based on admin options
function qtmedia_player_native_control_enqueue_scripts()
{
    $enable_audio_monitoring = get_option('qtmedia_enable_audio_monitoring', 'yes'); // Default is enabled
    $enable_video_monitoring = get_option('qtmedia_enable_video_monitoring', 'yes'); // Default is enabled

    if ($enable_audio_monitoring === 'yes' || $enable_video_monitoring === 'yes') {
        wp_enqueue_script(
            'qtmedia-native-control',
            plugin_dir_url(__FILE__) . 'qtmedia-native-control.js',
            [],
            '1.2',
            true
        );
        wp_localize_script('qtmedia-native-control', 'QTMediaSettings', [
            'audioMonitoring' => $enable_audio_monitoring,
            'videoMonitoring' => $enable_video_monitoring,
        ]);
    }
}
add_action('wp_enqueue_scripts', 'qtmedia_player_native_control_enqueue_scripts');

// Add admin menu option
function qtmedia_player_native_control_add_menu()
{
    add_options_page(
        'Webtonative MediaPlayer controls Settings',
        'WTN MediaPlayer controls',
        'manage_options',
        'qtmedia-player-settings',
        'qtmedia_player_native_control_settings_page'
    );
}
add_action('admin_menu', 'qtmedia_player_native_control_add_menu');

// Settings page HTML
function qtmedia_player_native_control_settings_page()
{
    if (!current_user_can('manage_options')) {
        return;
    }

    // Save settings if the form is submitted
    if (isset($_POST['qtmedia_settings_submit'])) {
        check_admin_referer('qtmedia_settings_nonce');
        $enable_audio_monitoring = isset($_POST['qtmedia_enable_audio_monitoring']) ? 'yes' : 'no';
        $enable_video_monitoring = isset($_POST['qtmedia_enable_video_monitoring']) ? 'yes' : 'no';
        update_option('qtmedia_enable_audio_monitoring', $enable_audio_monitoring);
        update_option('qtmedia_enable_video_monitoring', $enable_video_monitoring);
        echo '<div class="updated"><p>Settings saved.</p></div>';
    }

    $enable_audio_monitoring = get_option('qtmedia_enable_audio_monitoring', 'yes');
    $enable_video_monitoring = get_option('qtmedia_enable_video_monitoring', 'yes');
?>
    <div class="wrap">
        <h1>Webtonative MediaPlayer controls Settings</h1>
        <form method="post" action="">
            <?php wp_nonce_field('qtmedia_settings_nonce'); ?>
            <table class="form-table">
                <tr>
                    <th scope="row">Enable Audio Monitoring</th>
                    <td>
                        <input type="checkbox" name="qtmedia_enable_audio_monitoring" value="yes" <?php checked($enable_audio_monitoring, 'yes'); ?> />
                        <label for="qtmedia_enable_audio_monitoring">Enable monitoring of audio elements</label>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Enable Video Monitoring</th>
                    <td>
                        <input type="checkbox" name="qtmedia_enable_video_monitoring" value="yes" <?php checked($enable_video_monitoring, 'yes'); ?> />
                        <label for="qtmedia_enable_video_monitoring">Enable monitoring of video elements</label>
                    </td>
                </tr>
            </table>
            <p class="submit">
                <input type="submit" name="qtmedia_settings_submit" class="button-primary" value="Save Changes" />
            </p>
        </form>
    </div>
<?php
}

// Add default options on plugin activation
function qtmedia_player_native_control_activate()
{
    if (get_option('qtmedia_enable_audio_monitoring') === false) {
        add_option('qtmedia_enable_audio_monitoring', 'yes');
    }
    if (get_option('qtmedia_enable_video_monitoring') === false) {
        add_option('qtmedia_enable_video_monitoring', 'yes');
    }
}
register_activation_hook(__FILE__, 'qtmedia_player_native_control_activate');

// Remove options on plugin deactivation
function qtmedia_player_native_control_deactivate()
{
    delete_option('qtmedia_enable_audio_monitoring');
    delete_option('qtmedia_enable_video_monitoring');
}
register_deactivation_hook(__FILE__, 'qtmedia_player_native_control_deactivate');
