document.addEventListener('DOMContentLoaded', function () {
    if (!window.WTN) return;

    const isAndroidApp = window.WTN.isAndroidApp;
    const isLoggedIn = simpleIAPData.isLoggedIn;
    const iosSecretKey = simpleIAPData.iosSecretKey;

    document.querySelectorAll('.iap-button').forEach(button => {
        button.addEventListener('click', function () {
            if (!isLoggedIn) {
                alert('Please login to continue');
                return;
            }

            if(!isAndroidApp && !iosSecretKey) { 
                alert('Please configure the App store secret key in settings');
                return;
            }

            const dataToProcess = {
                productId: isAndroidApp ? button.dataset.googlePlayId : button.dataset.appStoreId,
                productType: button.dataset.productType,
                isConsumable: button.dataset.isConsumable === 'true',
            };

            button.disabled = true;
            button.textContent = 'Processing...';

            window.WTN.inAppPurchase({
                ...dataToProcess,
                callback: (data) => handlePaymentResponse(data, button),
            });
        });
    });

    function handlePaymentResponse(data, button) {
        button.disabled = false;
        button.textContent = 'Buy Now';

        if (!data.isSuccess) {
            alert('Payment failed');
            return;
        }

        const formData = new FormData();
        formData.append('action', 'simple_iap_verify');
        formData.append('nonce', simpleIAPData.nonce);
        formData.append('platform', /iPhone|iPad|iPod/.test(navigator.userAgent) ? 'ios' : 'android');
        formData.append('receipt', data.receiptData);

        fetch(simpleIAPData.ajax_url, {
            method: 'POST',
            body: formData,
        })
            .then(response => response.json())
            .then(result => {
                if (result.success) {
                    alert('Purchase successful!');
                } else {
                    alert('Verification failed: '+ result?.data?.message);
                }
            })
            .catch(error => {
                console.error('Error:', error);
                alert('Verification error: ' + error.message);
            });
    }
});
