(async function ($) {
  if (!WTN.isAndroidApp && !WTN.isIosApp) {
    return;
  }

  const nonce = webtonative_payment_settings.nonce;
  const resturl = webtonative_payment_settings.rest_url;

  const isLoggedIn = wtn_biometric_settings.isLoggedIn === '1';
  const iosSecretKey = wtn_biometric_settings.iosSecretKey;

  const btnBuyNowText = wtn_biometric_settings?.btn_buy_now_text ?? 'Buy Now';
  const btnProcessingText = wtn_biometric_settings?.btn_processing_text ?? 'Processing...';
  const btnSuccessText = wtn_biometric_settings?.btn_payment_completed_text ?? 'Payment completed';
  const btnFailedText = wtn_biometric_settings?.btn_failed_text ?? 'Payment failed';

  const response = await fetch(resturl + '/list');
  const data = await response.json();

  function getProductIds(productId) {
    return new Promise((res, rej) => {
      $.ajax({
        url: resturl + '/product',
        type: 'POST',
        contentType: 'application/json',
        data: JSON.stringify({
          productId: productId,
          platform: WTN.isAndroidApp ? 'ANDROID' : 'IOS',
        }),
        headers: {
          'X-WP-Nonce': nonce,
        },
        success: function (response) {
          const dataToProcess = {
            productId: response.productId,
            productType: response.productType === 'SUBS' ? 'SUBS' : 'INAPP',
            isConsumable: response.isConsumable === 'yes',
          };
          if (!dataToProcess.productId || !dataToProcess.productType) {
            rej();
            return;
          }
          res(dataToProcess);
        },
        error: function () {
          rej();
        },
      });
    });
  }

  async function processPayment() {
    const button = $(this);
    const productId = button.data('product_id') || button.val();
    if (!productId) {
      return;
    }

    function createOrder(data, dataToProcess) {
      let dataToSend = {
        productId: productId,
        platform: WTN.isAndroidApp ? 'ANDROID' : 'IOS',
        nativeProductId: dataToProcess.productId,
      };
      if (WTN.isIosApp) {
        dataToSend.receiptData = data;
      }
      if (WTN.isAndroidApp) {
        dataToSend = {
          ...dataToSend,
          ...data,
        };
      }
      $.ajax({
        url: resturl + '/order',
        type: 'POST',
        contentType: 'application/json',
        data: JSON.stringify(dataToSend),
        headers: {
          'X-WP-Nonce': nonce,
        },
        success: function (response) {
          if (response.status === 'success') {
            button.text(btnSuccessText);
            return;
          }
        },
        error: function (error) {
          alert(btnFailedText + JSON.stringify(error));
          button.text(btnFailedText);
        },
      });
    }

    button.text(btnProcessingText);
    button.prop('disabled', true);

    try {
      const productData = await getProductIds(productId);
      // alert('Product Data: ' + JSON.stringify(productData));
      WTN.inAppPurchase({
        ...productData,
        callback: function (data) {
          // paymentCallback(data, dataToProcess);
          button.prop('disabled', false);
          if (!data.isSuccess) {
            alert(btnFailedText);
            button.text(btnBuyNowText);
            return;
          }
          const receiptData = data.receiptData;
          createOrder(receiptData, { ...productData });
        },
      });
      button.prop('disabled', true);
    } catch (error) {
      console.log({ error });
    }

    return false;
  }

  // Loop through the buttons and update their text if `nativeProductId` exists
  $('.single_add_to_cart_button, .add_to_cart_button').each(function () {
    const button = $(this);
    const productId = button.data('product_id') || button.val();
    const nativeProductId = data?.[productId.toString()]?.[WTN.isIosApp ? 'appStore' : 'googlePlay'];

    if (nativeProductId) {
      // Create a new <button> element
      const newButton = $('<button>')
        .addClass(button.attr('class')) // Copy classes from the original anchor tag
        .text(btnBuyNowText)
        .attr('style', button.attr('style')) // Copy inline styles
        .data('product_id', productId); // Preserve data attributes

      // Replace the anchor tag with the new button
      button.replaceWith(newButton);
    }
  });

  // Event delegation for dynamically added buttons
  $(document).on('click', '.single_add_to_cart_button, .add_to_cart_button', async function (e) {
    e.stopPropagation();
    e.preventDefault();
    e.stopImmediatePropagation();

    if (!isLoggedIn) {
      alert('Please login to continue');
      return;
    }
    if(WTN.isIosApp && !iosSecretKey){
      alert("Please configure App store secret key in settings");
      return;
    }

    const button = $(this);
    const productId = button.data('product_id') || button.val();

    const nativeProductId = data?.[productId.toString()]?.[WTN.isIosApp ? 'appStore' : 'googlePlay'];
    if (!nativeProductId) return;

    await processPayment.call(this);
  });
})(jQuery);
