document.addEventListener('DOMContentLoaded', () => {

    const urlParams = new URLSearchParams(window.location.search);
    if (urlParams.has('logged_out')) {
        localStorage.setItem('wtnForcedLogout', 'true');
        // Remove the query parameter from the URL
        window.history.replaceState({}, document.title, window.location.pathname);
    }

    const activeExpireTime = +WTN_Biometric_Settings.delayTime * 60 * 1000; // minutes in milliseconds WTN_Biometric_Settings.delayTime
    let lastActiveTime = Date.now();

    const enableBiometric = document.getElementById('enable-biometric-auth');
    const biometricToggle = document.getElementById('wtn-biometric-settings');
    const loginBiometricBtnWrapper = document.getElementById('wtn-biometric-login');

    // Check if WordPress session cookie exists
    function isSessionExpired() {
        return !WTN_Biometric_Settings.isLoggedIn
    }

    // Check if forced logout flag is set
    function hasForcedLogout() {
        return localStorage.getItem('wtnForcedLogout') === 'true';
    }

    // Clear forced logout flag when user logs in again
    if (!isSessionExpired()) {
        localStorage.removeItem('wtnForcedLogout');
    }

    // Check biometric status and toggle visibility
    window.WTN.Biometric.checkStatus({
        callback: function (data) {
            if (data.isSuccess && data.hasTouchId) {
                // Check if admin has enabled biometric    
                if (!!WTN_Biometric_Settings.biometricEnabled) {                    
                    if (loginBiometricBtnWrapper && data.hasSecret && isSessionExpired() && !hasForcedLogout()){
                        loginBiometricBtnWrapper.style.display = 'block'; // Hide login button
                    }        
                    if (biometricToggle){
                        biometricToggle.style.display = 'block';
                    }
                }

                // Set checkbox state based on userSecret
                enableBiometric.checked = !!WTN_Biometric_Settings.userSecret;

                enableBiometric.addEventListener('change', handleBiometricToggle);
            } else {
                biometricToggle.style.display = 'none';
                loginBiometricBtnWrapper.style.display = 'none';
            }
        },
    });

    function handleBiometricToggle(e) {
        const isEnabled = e.target.checked;

        if (isEnabled) {
            const secret = WTN_Biometric_Settings.userSecret || generateToken();
            window.WTN.Biometric.saveSecret({
                secret,
                callback: function (res) {
                    if (res.isSuccess) {
                        updateBiometricState('enable', secret);
                    } else {
                        alert('Failed to enable biometric authentication.');
                        enableBiometric.checked = false;
                    }
                },
            });
        } else {
            window.WTN.Biometric.deleteSecret({
                callback: function (res) {
                    if (res.isSuccess) {
                        updateBiometricState('disable');
                    } else {
                        alert('Failed to disable biometric authentication.');
                        enableBiometric.checked = true;
                    }
                },
            });
        }
    }

    function updateBiometricState(action, secret = '') {
        fetch(WTN_Biometric_Settings.restApiUrl, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-WP-Nonce': WTN_Biometric_Settings.wpNonce,
            },
            body: JSON.stringify({ action, secret }),
        })
            .then((response) => response.json())
            .then((data) => {
                if (!data.success) {
                    console.error('Failed to update biometric state:', data.message);
                }
            })
            .catch((error) => console.error('Error:', error));
    }

    // handle promt on app resume
    // Event: When the document visibility changes
    document.addEventListener('visibilitychange', () => {
        if (isSessionExpired()) return;
        if (!WTN_Biometric_Settings.biometricEnabled) return;
        if (!WTN_Biometric_Settings.promptOnResume) return;
        if (document.visibilityState === 'hidden') {
            // App is inactive, record the time on global level
            lastActiveTime = Date.now();
        } else if (document.visibilityState === 'visible') {
            // App is active again, check the time difference
            const currentTime = Date.now();
            const timeElapsed = currentTime - lastActiveTime;

            if (timeElapsed > activeExpireTime) {
                showBiometricPrompt();
            }
        }
    });

    // handle promt on app open
    if (!isSessionExpired() && WTN_Biometric_Settings.biometricEnabled && WTN_Biometric_Settings.promptOnOpen){
        window.WTN.appFirstLoad().then(function(value){
            if (!value.result) return;
            showBiometricPrompt()
        });
    }
    
    function showBiometricPrompt() {
        window.WTN.Biometric.show({
            prompt: "Authenticate to continue!",
            callback: function (data) {
                if (!data.isSuccess && data.value === 'Authentication failed') {
                    return
                }
                if (!data.isSuccess) {
                    window.WTN.closeApp();
                    return
                }
            },
        });
    }

    // Generate a random secret token
    function generateToken() {
        return [...Array(32)].map(() => Math.random().toString(36)[2]).join('');
    }

    // Function to get query parameters
    function getQueryParam(param) {
        const urlParams = new URLSearchParams(window.location.search);
        return urlParams.get(param);
    }
});
