<?php
$settings = get_option('wtn_radio_player_settings', []);
$enabled = $settings['enabled'] ?? false;
$tracks = $settings['tracks'] ?? [];
?>

<div class="wrap">
    <h1>WebToNative Radio Player Settings</h1>
    <form method="post" action="options.php">
        <?php settings_fields('wtn_radio_player_settings_group'); ?>

        <table class="form-table">
            <tr valign="top">
                <th scope="row">Enable Radio Player</th>
                <td>
                    <input type="checkbox" name="wtn_radio_player_settings[enabled]" value="1" <?php checked($enabled, 1); ?> />
                    <p class="description">Enable or disable the radio player feature.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Tracks</th>
                <td>
                    <div id="track-list">
                        <?php foreach ($tracks as $index => $track): ?>
                            <div class="track-item">
                                <input type="text" name="wtn_radio_player_settings[tracks][<?php echo $index; ?>][name]" placeholder="Track Name" value="<?php echo esc_attr($track['name'] ?? ''); ?>" />
                                <input type="url" name="wtn_radio_player_settings[tracks][<?php echo $index; ?>][url]" placeholder="Track URL" value="<?php echo esc_url($track['url'] ?? ''); ?>" />
                                <input type="url" name="wtn_radio_player_settings[tracks][<?php echo $index; ?>][image]" placeholder="Image URL" value="<?php echo esc_url($track['image'] ?? ''); ?>" />
                                <button type="button" class="remove-track">Remove</button>
                            </div>
                        <?php endforeach; ?>
                    </div>
                    <button type="button" id="add-track">Add Track</button>
                    <p class="description">Add or remove tracks for the radio player. Each track should have a name, URL, and an optional image.</p>
                </td>
            </tr>
        </table>

        <?php submit_button(); ?>
    </form>
</div>

<style>
    .track-item {
        margin-bottom: 15px;
        /* Add gap between input rows */
    }

    .track-item input {
        margin-bottom: 5px;
        /* Add gap between inputs */
    }
</style>

<script>
    document.getElementById('add-track').addEventListener('click', function() {
        const trackList = document.getElementById('track-list');
        const index = trackList.children.length;
        const trackItem = document.createElement('div');
        trackItem.className = 'track-item';
        trackItem.innerHTML = `
            <input type="text" name="wtn_radio_player_settings[tracks][${index}][name]" placeholder="Track Name" />
            <input type="url" name="wtn_radio_player_settings[tracks][${index}][url]" placeholder="Track URL" />
            <input type="url" name="wtn_radio_player_settings[tracks][${index}][image]" placeholder="Image URL" />
            <button type="button" class="remove-track">Remove</button>
        `;
        trackList.appendChild(trackItem);
    });

    document.addEventListener('click', function(e) {
        if (e.target.classList.contains('remove-track')) {
            e.target.parentElement.remove();
        }
    });

    // Validate form before submitting
    document.querySelector('form').addEventListener('submit', function(e) {
        const trackItems = document.querySelectorAll('.track-item');
        let hasError = false;

        trackItems.forEach(function(item) {
            const nameInput = item.querySelector('input[name$="[name]"]');
            const urlInput = item.querySelector('input[name$="[url]"]');

            // Check if name and URL are empty
            if (!nameInput.value || !urlInput.value) {
                alert('Both Track Name and Track URL are required.');
                hasError = true;
                return false; // Prevent submission
            }
        });

        if (hasError) {
            e.preventDefault(); // Prevent form submission
        }
    });
</script>