(function ($) {
    let tracks = wtnPlayerData.tracks || [];
    let currentTrackIndex = 0;
    let audio = new Audio();

    function loadTrack(index) {
        let track = tracks[index];
        if (!track) return;

        $('#track-title').text(track.name || 'Unknown Track');
        $('#track-image').attr('src', track.image || '');
        audio.src = track.url || '';

        // Disable/Enable Prev and Next buttons based on track availability
        $('#wtn-prev').prop('disabled', index === 0).toggle(tracks.length > 1);
        $('#wtn-next').prop('disabled', index === tracks.length - 1).toggle(tracks.length > 1);
    }

    // Play/Pause Button
    $('#wtn-play-pause').on('click', function () {
        if (audio.paused) {
            audio.play();
            window?.WTN?.MediaPlayer?.playMedia({ url: tracks[currentTrackIndex]?.url, image: tracks[currentTrackIndex]?.image });
            $(this).text('⏸');
        } else {
            audio.pause();
            window?.WTN?.MediaPlayer?.pauseMedia();
            $(this).text('▶');
        }
    });

    // Previous Button
    $('#wtn-prev').on('click', function () {
        if (currentTrackIndex > 0) {
            currentTrackIndex--;
            loadTrack(currentTrackIndex);
            audio.play();
            window?.WTN?.MediaPlayer?.playMedia({ url: tracks[currentTrackIndex]?.url, image: tracks[currentTrackIndex]?.image });
            $('#wtn-play-pause').text('⏸'); // Update button state
        }
    });

    // Next Button
    $('#wtn-next').on('click', function () {
        if (currentTrackIndex < tracks.length - 1) {
            currentTrackIndex++;
            loadTrack(currentTrackIndex);
            audio.play();
            window?.WTN?.MediaPlayer?.playMedia({ url: tracks[currentTrackIndex]?.url, image: tracks[currentTrackIndex]?.image });
            $('#wtn-play-pause').text('⏸'); // Update button state
        }
    });

    // Hide Prev/Next buttons if only one track is present
    if (tracks.length === 1) {
        $('#wtn-prev, #wtn-next').hide();
    }

    // Load the initial track without autoplay
    if (tracks.length > 0) {
        loadTrack(currentTrackIndex);
    }
})(jQuery);
