<?php
/*
Plugin Name: WebToNative Radio Player
Description: A minimal radio player plugin for WordPress with customizable tracks and shortcode support.
Version: 1.1
Author: webtonative
*/

// Enqueue frontend assets
function wtn_enqueue_assets()
{
    wp_enqueue_style('wtn-player-css', plugin_dir_url(__FILE__) . 'css/player.css');
    wp_enqueue_script('wtn-player-js', plugin_dir_url(__FILE__) . 'js/player.js', array('jquery'), null, true);

    // Pass settings to JavaScript
    $player_settings = get_option('wtn_radio_player_settings', []);
    wp_localize_script('wtn-player-js', 'wtnPlayerData', $player_settings);
}
add_action('wp_enqueue_scripts', 'wtn_enqueue_assets');

// Add admin menu for settings
function wtn_add_admin_menu()
{
    add_options_page(
        'Radio Player Settings',
        'WTN Radio Player',
        'manage_options',
        'wtn-radio-player',
        'wtn_render_settings_page',
    );
}
add_action('admin_menu', 'wtn_add_admin_menu');

// Render the settings page
function wtn_render_settings_page()
{
    include plugin_dir_path(__FILE__) . 'admin/settings-page.php';
}

// Register settings
function wtn_register_settings()
{
    register_setting('wtn_radio_player_settings_group', 'wtn_radio_player_settings');
}
add_action('admin_init', 'wtn_register_settings');

// Shortcode to render the player
function wtn_radio_player_shortcode()
{
    $settings = get_option('wtn_radio_player_settings', []);
    if (empty($settings['enabled']) || empty($settings['tracks'])) {
        return ''; // Do not render the player if disabled or no tracks are set
    }

    ob_start();
?>
    <div id="wtn-player">
        <div id="track-info">
            <img id="track-image" src="" alt="Track Image">
            <div id="track-title">Track Name</div>
        </div>
        <div id="wtn-controls">
            <button id="wtn-prev" class="round-btn">⏮</button>
            <button id="wtn-play-pause" class="round-btn">▶</button>
            <button id="wtn-next" class="round-btn">⏭</button>
        </div>
    </div>
<?php
    return ob_get_clean();
}
add_shortcode('wtn_radio_player', 'wtn_radio_player_shortcode');
